@@ -397,7 +397,7 @@ class OpenEVSE:
             raise UnsupportedFeature
         url = f"{self.url}override"
 
-        data: dict[str, Any] = {}
+        data: dict[str, Any] = await self.get_override()
 
         if state not in ["active", "disabled", None]:
             _LOGGER.error("Invalid override state: %s", state)
@@ -644,7 +644,6 @@ class OpenEVSE:
         return False
 
     # HTTP Posting of grid voltage
-
     async def grid_voltage(self, voltage: int | None = None) -> None:
         """Send pushed sensor data to grid voltage."""
         if not self._version_check("4.0.0"):
@@ -665,7 +664,6 @@ class OpenEVSE:
             _LOGGER.debug("Voltage posting response: %s", response)
 
     # Self production HTTP Posting
-
     async def self_production(
         self,
         grid: int | None = None,
@@ -743,7 +741,7 @@ class OpenEVSE:
             raise UnsupportedFeature
 
         url = f"{self.url}limit"
-        data: Dict[str, Any] = {}
+        data: Dict[str, Any] = await self.get_limit()
         valid_types = ["time", "energy", "soc", "range"]
 
         if limit_type not in valid_types:
@@ -1274,6 +1272,7 @@ class OpenEVSE:
             return round(self._status["voltage"] * self._status["amp"], 2)
         return None
 
+    # Shaper values
     @property
     def shaper_active(self) -> bool | None:
         """Return if shper is active."""
@@ -1304,6 +1303,14 @@ class OpenEVSE:
             return self._status["shaper_max_pwr"]
         return None
 
+    @property
+    def shaper_updated(self) -> bool:
+        """Return shaper updated boolean."""
+        if self._status is not None and "shaper_updated" in self._status:
+            return self._status["shaper_updated"]
+        return False
+
+    # Vehicle values
     @property
     def vehicle_soc(self) -> int | None:
         """Return battery level."""
